@@ -19,7 +19,8 @@
 #include <assert.h>
 #include "grib_api.h"
 
-int main(int argc, char** argv) {
+int main(int argc, char** argv)
+{
     int err = 0;
     double *values = NULL;
     size_t values_len= 0;
@@ -37,9 +38,10 @@ int main(int argc, char** argv) {
     long numberOfPointsAlongAMeridian;
 
     double average = 0;
+    char* packingType = NULL;
 
     FILE* in = NULL;
-    char* filename = "../../data/regular_latlon_surface.grib1";
+    const char* filename = "../../data/regular_latlon_surface.grib1";
     grib_handle *h = NULL;
 
     in = fopen(filename,"r");
@@ -90,10 +92,17 @@ int main(int argc, char** argv) {
     GRIB_CHECK(grib_get_double(h,"iDirectionIncrementInDegrees",&iDirectionIncrementInDegrees),0);
     printf("iDirectionIncrementInDegrees=%g\n",iDirectionIncrementInDegrees);
 
+    /* get as string */
+    GRIB_CHECK(grib_get_length(h, "packingType", &len), 0);
+    packingType = (char*)malloc(len*sizeof(char));
+    grib_get_string(h, "packingType", packingType, &len);
+    printf("packingType=%s\n", packingType);
+    free(packingType);
+
     /* get the size of the values array*/
     GRIB_CHECK(grib_get_size(h,"values",&values_len),0);
 
-    values = malloc(values_len*sizeof(double));
+    values = (double*)malloc(values_len*sizeof(double));
 
     /* get data values*/
     GRIB_CHECK(grib_get_double_array(h,"values",values,&values_len),0);
@@ -109,16 +118,17 @@ int main(int argc, char** argv) {
     printf("There are %d values, average is %g\n",(int)values_len,average);
 
     {
+        int eq = 0;
         /* Now retrieve the value of the key "file" */
         char file[256]={0,};
         GRIB_CHECK(grib_get_length(h, "file", &len),0);
         assert(len == 1+strlen(filename));
         grib_get_string(h, "file", file, &len);
-        assert( strcmp(file, filename) == 0 );
+        eq = strcmp(file, filename);
+        assert( eq == 0 );
     }
 
     grib_handle_delete(h);
-
     fclose(in);
     return 0;
 }
