@@ -20,7 +20,8 @@
 
 #include "grib_api.h"
 
-int main(int argc, char** argv) {
+int main(int argc, char** argv)
+{
 	int err = 0;
 
 	size_t i = 0;
