@@ -19,12 +19,13 @@
 
 #include "grib_api.h"
 
-void usage(char* prog) {
+void usage(const char* prog) {
   printf("usage: %s filename\n",prog);
   exit(1);
 }
 
-int main(int argc, char** argv) {
+int main(int argc, char** argv)
+{
   int err = 0,i;
   double *values = NULL;
   double max,min,average;
