@@ -19,7 +19,8 @@
 #include <assert.h>
 #include "grib_api.h"
 
-int main(int argc, char** argv) {
+int main(int argc, char** argv)
+{
   int err = 0, is_missing = 0;
 
   FILE* in = NULL;
@@ -42,6 +43,7 @@ int main(int argc, char** argv) {
   out = fopen(outfile,"w");
   if(!out) {
     printf("ERROR: unable to open output file %s\n",outfile);
+        fclose(in);
     return 1;
   }
 
