@@ -9,9 +9,9 @@
 
 . ./include.sh
 
-${examples_dir}multi_write > /dev/null
+${examples_dir}f_multi_write > /dev/null
 
-${tools_dir}/grib_cmp ${data_dir}/multi_created.grib2 multi_created.grib2
+${tools_dir}/grib_compare ${data_dir}/multi_created.grib2 multi_created.grib2
 
 #	rm -f multi_created.grib2
 
