@@ -10,3 +10,9 @@
 . ./include.sh
 
 ${examples_dir}f_set > /dev/null
+
+${examples_dir}f_set_gvc > /dev/null
+[ -f out_gvc.grib2 ]
+
+rm -f out.grib1 out_gvc.grib2
+
