@@ -1224,7 +1224,7 @@ int grib_f_new_from_template_(int* gid, char* name , int lname){
   char fname[1024];
   grib_handle *h = NULL;
 
-  h = grib_handle_new_from_template(NULL,cast_char(fname,name,lname));
+  h = grib_handle_new_from_samples(NULL,cast_char(fname,name,lname));
   /*   grib_context_set_debug(h->context,1);*/
 
   if(h){
@@ -2366,9 +2366,10 @@ int grib_f_find_nearest_four_single_(int* gid,int* is_lsm,
     double* inlat,double* inlon,
     double* outlats,double* outlons,
     double* values,double* distances,
-    int* indexes) {
+    int* indexes)
+{
     grib_nearest* nearest=NULL;
-    int err=0;
+    int err=0, result=0;
     unsigned long flags=0;
     size_t len=4;
     grib_handle *h = get_handle(*gid);
@@ -2378,8 +2379,11 @@ int grib_f_find_nearest_four_single_(int* gid,int* is_lsm,
     nearest=grib_nearest_new(h,&err);
     if (err!=GRIB_SUCCESS) return err;
 
-    return grib_nearest_find(nearest,h,*inlat,*inlon,
+    result = grib_nearest_find(nearest,h,*inlat,*inlon,
     flags,outlats,outlons,values,distances,indexes,&len);
+  	
+    grib_nearest_delete(nearest);
+    return result;
 }
 int grib_f_find_nearest_four_single__(int* gid,int* is_lsm,
     double* inlats,double* inlons,
@@ -2387,7 +2391,7 @@ int grib_f_find_nearest_four_single__(int* gid,int* is_lsm,
     double* values,double* distances,
     int* indexes) {
 
-  return grib_f_find_nearest_single_(gid,is_lsm,
+  return grib_f_find_nearest_four_single_(gid,is_lsm,
     inlats,inlons,outlats,outlons,values,
     distances,indexes);
 }
@@ -2397,7 +2401,7 @@ int grib_f_find_nearest_four_single(int* gid,int* is_lsm,
     double* values,double* distances,
     int* indexes) {
 
-  return grib_f_find_nearest_single_(gid,is_lsm,
+  return grib_f_find_nearest_four_single_(gid,is_lsm,
     inlats,inlons,outlats,outlons,values,
     distances,indexes);
 }
@@ -2473,8 +2477,6 @@ int grib_f_find_nearest_multiple(int* gid,int* is_lsm,
 }
 
 
-
-
 int grib_f_get_real8_array_(int* gid, char* key, double*val, int* size, int len){
 
   grib_handle *h = get_handle(*gid);
@@ -2507,9 +2509,7 @@ int grib_f_set_force_real8_array(int* gid, char* key, double *val, int* size, in
 int grib_f_set_force_real8_array_(int* gid, char* key, double*val, int* size, int len){
 
   grib_handle *h = get_handle(*gid);
-
   char buf[1024];
-
   size_t lsize = *size;
 
   if(!h)   return GRIB_INVALID_GRIB;
@@ -2521,9 +2521,7 @@ int grib_f_set_force_real8_array_(int* gid, char* key, double*val, int* size, in
 int grib_f_set_real8_array_(int* gid, char* key, double*val, int* size, int len){
 
   grib_handle *h = get_handle(*gid);
-
   char buf[1024];
-
   size_t lsize = *size;
 
   if(!h)   return GRIB_INVALID_GRIB;
