@@ -186,7 +186,7 @@ grib_section *grib_create_root_section(const grib_context *context, grib_handle
 grib_accessor *grib_accessor_factory(grib_section *p, grib_action *creator, const long len, grib_arguments *params);
 void grib_push_accessor(grib_accessor *a, grib_block_of_accessors *l);
 void grib_section_post_init(grib_section *s);
-void grib_section_adjust_sizes(grib_section *s, int update, int depth);
+int grib_section_adjust_sizes(grib_section *s, int update, int depth);
 int grib_get_block_length(grib_section *s, size_t *l);
 grib_accessor *find_paddings(grib_section *s);
 void grib_update_paddings(grib_section *s);
@@ -360,6 +360,8 @@ int grib_get_g1_message_size(grib_handle *h, grib_accessor *tl, grib_accessor *s
 
 /* grib_accessor_class_sprintf.c */
 
+/* grib_accessor_class_getenv.c */
+
 /* grib_accessor_class_round.c */
 
 /* grib_accessor_class_spectral_truncation.c */
@@ -427,6 +429,7 @@ second_order_packed *grib_get_second_order_groups(grib_context *c, const unsigne
 /* grib_accessor_class_data_apply_bitmap.c */
 
 /* grib_accessor_class_data_apply_boustrophedonic.c */
+/* grib_accessor_class_data_apply_boustrophedonic_bitmap.c */
 
 /* grib_accessor_class_data_secondary_bitmap.c */
 
@@ -508,7 +511,8 @@ int grib_index_select_long(grib_index *index, const char *skey, long value);
 int grib_index_select_double(grib_index *index, const char *skey, double value);
 int grib_index_select_string(grib_index *index, const char *skey, char *value);
 grib_handle *grib_index_get_handle(grib_field *field, int *err);
-void grib_index_dump(grib_index *index);
+void grib_index_dump(FILE* fout, grib_index *index);
+int grib_index_dump_file(FILE* fout, const char* filename);
 char *grib_get_field_file(grib_index *index, off_t *offset);
 grib_handle *grib_handle_new_from_index(grib_index *index, int *err);
 void grib_index_rewind(grib_index *index);
@@ -645,6 +649,8 @@ void grib_dump_footer(grib_dumper *d, grib_handle *h);
 
 /* grib_dumper_class_keys.c */
 
+/* grib_dumper_class_json.c */
+
 /* grib_dumper_class_c_code.c */
 
 /* grib_dumper_class_wmo.c */
@@ -668,7 +674,7 @@ long grib_get_api_version(void);
 void grib_print_api_version(FILE *out);
 grib_context *grib_context_get_default(void);
 grib_context *grib_context_new(grib_context *parent);
-char *grib_context_full_path(grib_context *c, const char *basename);
+char *grib_context_full_defs_path(grib_context *c, const char *basename);
 void grib_context_free(const grib_context *c, void *p);
 void grib_context_free_persistent(const grib_context *c, void *p);
 void grib_context_reset(grib_context *c);
@@ -763,6 +769,7 @@ int grib_handle_apply_action(grib_handle *h, grib_action *a);
 int grib_handle_prepare_action(grib_handle *h, grib_action *a);
 void grib_multi_support_on(grib_context *c);
 void grib_multi_support_off(grib_context *c);
+void grib_multi_support_reset_file(grib_context* c, FILE* f);
 void grib_gts_header_on(grib_context *c);
 void grib_gts_header_off(grib_context *c);
 int grib_get_gribex_mode(grib_context *c);
@@ -832,10 +839,6 @@ int grib_keys_iterator_next(grib_keys_iterator *kiter);
 const char *grib_keys_iterator_get_name(grib_keys_iterator *kiter);
 grib_accessor *grib_keys_iterator_get_accessor(grib_keys_iterator *kiter);
 int grib_keys_iterator_delete(grib_keys_iterator *kiter);
-int grib_keys_iterator_get_long(grib_keys_iterator *kiter, long *v, size_t *len);
-int grib_keys_iterator_get_double(grib_keys_iterator *kiter, double *v, size_t *len);
-int grib_keys_iterator_get_string(grib_keys_iterator *kiter, char *v, size_t *len);
-int grib_keys_iterator_get_bytes(grib_keys_iterator *kiter, unsigned char *v, size_t *len);
 int grib_keys_iterator_get_native_type(grib_keys_iterator *kiter);
 
 /* grib_parse_utils.c */
@@ -1058,6 +1061,7 @@ int parse_keyval_string(char* grib_tool, char* arg, int values_required, int def
 int is_productDefinitionTemplateNumber_EPS(long productDefinitionTemplateNumber);
 int is_productDefinitionTemplateNumber_Chemical(long productDefinitionTemplateNumber);
 int is_productDefinitionTemplateNumber_Aerosol(long productDefinitionTemplateNumber);
+int is_index_file(const char* filename);
 
 /* compile.c */
 void grib_compile_flags(grib_compiler *c, long flags);
