@@ -194,6 +194,7 @@ static void check_definitions_version(grib_handle* h)
 static grib_handle* grib_handle_create ( grib_handle  *gl, grib_context* c,void* data, size_t buflen )
 {
 	grib_action* next = NULL;
+	int err = 0;
 
 	if ( gl == NULL )
 		return NULL;
@@ -234,7 +235,13 @@ static grib_handle* grib_handle_create ( grib_handle  *gl, grib_context* c,void*
 		next = next->next;
 	}
 
-	grib_section_adjust_sizes ( gl->root,0,0 );
+	err = grib_section_adjust_sizes ( gl->root,0,0 );
+	if (err)
+    {
+        grib_handle_delete ( gl );
+        return NULL;
+    }
+    
 	grib_section_post_init ( gl->root );
 
 	check_definitions_version(gl);
@@ -267,7 +274,8 @@ grib_handle* grib_handle_new_from_samples ( grib_context* c, const char* name )
 
 	g=grib_external_template ( c,name );
 	if ( !g )
-		grib_context_log (c,GRIB_LOG_ERROR,"Unable to locate sample file %s.tmpl\n                    in %s",name,c->grib_samples_path);
+		grib_context_log (c,GRIB_LOG_ERROR,"Unable to load sample file %s.tmpl\n                    in %s",
+                name,c->grib_samples_path);
 
 	return g;
 }
@@ -1280,7 +1288,6 @@ static void grib2_build_message ( grib_context* context,unsigned char* sections[
 	grib_encode_unsigned_long ( *data,msglen,&bitp,64 );
 
 	*len=msglen;
-
 }
 
 void grib_multi_support_on ( grib_context* c )
@@ -1295,6 +1302,20 @@ void grib_multi_support_off ( grib_context* c )
 	c->multi_support_on=0;
 }
 
+/* For multi support mode: Reset all file handles equal to f. See GRIB-249 */
+void grib_multi_support_reset_file(grib_context* c, FILE* f)
+{
+	grib_multi_support* gm = NULL;
+	if ( !c ) c = grib_context_get_default();
+	gm = c->multi_support;
+	while ( gm ) {
+		if ( gm->file == f ) {
+			gm->file = NULL;
+		}
+		gm=gm->next;
+	}
+}
+
 void grib_gts_header_on ( grib_context* c )
 {
 	if ( !c ) c=grib_context_get_default();
@@ -1358,7 +1379,6 @@ static grib_multi_support* grib_get_multi_support ( grib_context* c, FILE* f )
 	return gm;
 }
 
-
 void grib_multi_support_reset ( grib_context* c )
 {
 	grib_multi_support* gm=c->multi_support;
@@ -1376,7 +1396,6 @@ void grib_multi_support_reset ( grib_context* c )
 		grib_context_free ( c,gm );
 		gm=NULL;
 	}
-
 }
 
 static grib_multi_support* grib_multi_support_new ( grib_context* c )
@@ -1398,4 +1417,3 @@ static grib_multi_support* grib_multi_support_new ( grib_context* c )
 	return gm;
 }
 
-
