@@ -38,6 +38,7 @@ grib_options_help grib_options_help_list[] ={
   {"G",0,"GRIBEX compatibility mode.\n"},
   {"i:","index",
     "\n\t\tData value corresponding to the given index is printed.\n"},
+  {"j",0,"JSON mode (JavaScript Object Notation).\n"},
   {"l:","Latitude,Longitude[,MODE,file]",
    "\n\t\tValue close to the point of a Latitude/Longitude."
    "\n\t\tAllowed values for MODE are:"
@@ -49,9 +50,9 @@ grib_options_help grib_options_help_list[] ={
    "\n\t\tAll the keys belonging to namespace are printed.\n"},
   {"m",0,"Mars keys are printed.\n"},
   {"o:","output_grib_file",
-   "\n\t\tOutput grib is written to ouput_grib_file."
-   "\n\t\tIf an ouput grib file is required and -o is not used, the"
-   " ouput grib is written to filtered.out\n"},
+   "\n\t\tOutput grib is written to output_grib_file."
+   "\n\t\tIf an output grib file is required and -o is not used, the"
+   " output grib is written to filtered.out\n"},
   {"p:","key[:{s/d/l}],key[:{s/d/l}],...",
    "\n\t\tDeclaration of keys to print."
    "\n\t\tFor each key a string (key:s) or a double (key:d) or a long (key:l)"
@@ -92,6 +93,7 @@ grib_options_help grib_options_help_list[] ={
   {"T:","T | B","Message type. T->GTS, B->BUFR. The input file is interpreted according to the message type.\n"},
   {"V",0,"Version.\n"},
   {"W:","width","\n\t\tMinimum width of each column in output. Default is 10.\n"},
+  {"X:","offset","\n\t\tInput file offset in bytes. Processing of the input file will start from \"offset\".\n"},
   {"x",0,"Fast parsing option, only headers are loaded.\n"},
   {"k:","key1,key2,...","\n\t\tSpecify a list of keys to index on. By default the input files are indexed on the MARS keys.\n"}
 
@@ -99,9 +101,9 @@ grib_options_help grib_options_help_list[] ={
 
 int grib_options_help_count=sizeof(grib_options_help_list)/sizeof(grib_options_help);
 
-char* grib_options_get_option(const char* id) {
+char* grib_options_get_option(const char* id)
+{
     int i=0;
-
     for (i=0; i<grib_options_count; i++) {
         if (!strcmp(id,grib_options[i].id))
             return grib_options[i].value;
@@ -109,9 +111,9 @@ char* grib_options_get_option(const char* id) {
     return NULL;
 }
 
-int grib_options_command_line(const char* id) {
+int grib_options_command_line(const char* id)
+{
     int i=0;
-
     for (i=0; i<grib_options_count; i++) {
         if (!strcmp(id,grib_options[i].id))
             return grib_options[i].command_line;
@@ -119,9 +121,9 @@ int grib_options_command_line(const char* id) {
     return 0;
 }
 
-int grib_options_on(const char* id) {
+int grib_options_on(const char* id)
+{
     int i=0;
-
     for (i=0; i<grib_options_count; i++) {
         if (!strcmp(id,grib_options[i].id))
             return grib_options[i].on;
@@ -190,6 +192,9 @@ int grib_process_runtime_options(grib_context* context,int argc,char** argv,grib
     if (grib_options_on("l:"))
         options->latlon=grib_options_get_option("l:");
 
+    if (grib_options_on("X:"))
+        options->infile_offset=atol(grib_options_get_option("X:"));
+
     has_output=grib_options_on("U");
     has_input_extra=grib_options_on("I");
     options->repack=grib_options_on("r");
